<?php 


$prefix = 'eSMS';
$panel  = new \TDP\OptionsKit( $prefix );
$panel->set_page_title( __( 'eSMS Notify Settings' ) );

/**
 * Setup the menu for the options panel.
 *
 * @param array $menu
 *
 * @return array
 */
function eSMS_setup_menu( $menu ) {
	// These defaults can be customized
	$menu['parent'] = 'options-general.php';
	$menu['menu_title'] = 'Settings Panel';
	$menu['capability'] = 'manage_options';

	$menu['page_title'] = __( 'eSMS Notify' );
	$menu['menu_title'] = $menu['page_title'];

	return $menu;
}

add_filter( 'eSMS_menu', 'eSMS_setup_menu' );

/**
 * Register settings tabs.
 *
 * @param array $tabs
 *
 * @return array
 */
function eSMS_register_settings_tabs( $tabs ) {
	return array(
		'general' => __( 'Gateway Settings' ),
		'template' => __( 'Template Settings' ),
	);
}

add_filter( 'eSMS_settings_tabs', 'eSMS_register_settings_tabs' );

/**
 * Register settings subsections (optional)
 *
 * @param array $subsections
 *
 * @return array
 */
function eSMS_register_settings_subsections( $subsections ) {
	return $subsections;
}

add_filter( 'eSMS_registered_settings_sections', 'eSMS_register_settings_subsections' );

/**
 * Register settings fields for the options panel.
 *
 * @param array $settings
 *
 * @return array
 */
function eSMS_register_settings( $settings ) {
	$settings = array(
		'general' => array(
			array(
				'id'   => 'sms_status',
				'name' => __( 'Notification' ),
				'desc' => __( '<b>Enable Or Disable SMS Notification</b>.' ),
				'type' => 'select',
				'options' => array(
					'on' => 'On',
					'Off' => 'Off'

				)
			),
			array(
				'id'   => 'api_token',
				'name' => __( 'API Token' ),
				'desc' => __( '<b style="color:red">Enter Your eSMS Api Token Here</b>.' ),
				'type' => 'text',
			),
			array(
				'id'   => 'sender_id',
				'name' => __( 'Sender ID' ),
				'desc' => __('<b>Enter Your eSMS Masking / Non Masking Sender ID Here.</b>'),
				'type' => 'text',
				'class' =>'sender_id'
	
			),
			array(
				'id'   => 'admin_phone',
				'name' => __( 'Admin Phone Number' ),
				'desc' => __('Enter Your Phone Number to get New Order Notification. Exmaple: 8801742802367'),
				'type' => 'text',
				'class' =>'sender_id'
	
			),
			array(
				'id'   => 'balance',
				'desc' => __(getBalance()),
				
	
			),
		
		),
		'template' => array(
			array(
				'id'   => 'neworder',
				'name' => __( 'New Order Template' ),
				'std' => __('Hello {billing_name}, thank you for placing your order #{order_id} with {site_name}.

{site_url}'),
				'desc' => __( '<b>You may use these variables:   {order_id} , {client_name} , {amount} </b>' ),
				'type' => 'textarea',
				
			),
			array(
				'id'   => 'ordercomplete',
				'name' => __( 'New Order Template' ),
				'std' => __('Hello {billing_name}, your order #{order_id} with {site_name} has been completed.

Thanks for being with us.
{site_url}'),
				'desc' => __( '<b>You may use these variables:   {order_id} , {client_name} , {amount} </b>' ),
				'type' => 'textarea',
				
			),
			
		)
	);

	return $settings;
}

add_filter( 'eSMS_registered_settings', 'eSMS_register_settings' );

function getBalance(){
	$cred = get_option( 'eSMS_settings' );
	$endpoint = "https://login.esms.com.bd/api/v3/balance";
	$args = array(
    'headers' => array(
        'Authorization' => 'Bearer ' .$cred['api_token']
    )
);
	$response = wp_remote_get( $endpoint, $args );
	$response_body = json_decode(wp_remote_retrieve_body( $response ));
	$response_code = wp_remote_retrieve_response_code( $response );
	if ($response_code == 200) {
		$balance = $response_body->data->remaining_unit;
		return __('<b style="color:green">Your eSMS balance is: BDT '.$balance.'</b>');
	}else{
		return __('<b style="color:red">Invalid Api Token</b>.');
	}
	
}


